==> open-xchange-mobile-api-facade_1.4.5.orig.tar.bz2: open-xchange-mobile-api-facade-1.4.5/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/weakforce/WeakforceService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.weakforce;

import com.openexchange.mobile.api.facade.auth.LoginCredentials;
import com.openexchange.mobile.api.facade.configuration.HostConfiguration;
import com.openexchange.mobile.api.facade.connectors.impl.WeakforceAllowConnector;
import com.openexchange.mobile.api.facade.connectors.impl.WeakforceReportConnector;
import com.openexchange.mobile.api.facade.exceptions.ApiFacadeException;
import com.openexchange.mobile.api.facade.utils.WeakforceUtil;
import com.openexchange.mobile.api.facade.weakforce.models.AllowResponse;
import com.openexchange.mobile.api.facade.weakforce.models.LTAttrs;
import com.openexchange.mobile.api.facade.weakforce.models.LoginTupleAllow;
import com.openexchange.mobile.api.facade.weakforce.models.LoginTupleReport;
import com.openexchange.mobile.api.facade.weakforce.models.ReportResponse;

public class WeakforceService {

    public AllowResponse allow(HostConfiguration configuration, LoginCredentials credentials) {
        LoginTupleAllow requestBody = createLoginTupleAllow(configuration, credentials);
        WeakforceAllowConnector connector = new WeakforceAllowConnector(configuration, requestBody);
        return connector.execute();
    }

    /*private*/ LoginTupleAllow createLoginTupleAllow(HostConfiguration configuration, LoginCredentials credentials) {
        String passwordHash = WeakforceUtil.generatePasswordHash(configuration, credentials);
        LTAttrs attributes = createAttributes(credentials);
        return new LoginTupleAllow(credentials.getUsername(), passwordHash, credentials.getRemoteIp(), attributes);
    }

    public void report(HostConfiguration configuration, LoginCredentials credentials, boolean loginSuccessful, boolean policyReject) {
        LoginTupleReport requestBody = createLoginTupleReport(configuration, credentials, loginSuccessful, policyReject);
        WeakforceReportConnector connector = new WeakforceReportConnector(configuration, requestBody);
        ReportResponse response = connector.execute();
        if (response == null || !"ok".equals(response.getStatus())) {
            throw ApiFacadeException.internalServerError("Failed to connect to weakforce");
        }
    }

    /*private*/ LoginTupleReport createLoginTupleReport(HostConfiguration configuration, LoginCredentials credentials, boolean loginSuccessful, boolean policyReject) {
        String passwordHash = WeakforceUtil.generatePasswordHash(configuration, credentials);
        LTAttrs attributes = createAttributes(credentials);
        return new LoginTupleReport(credentials.getUsername(), passwordHash, credentials.getRemoteIp(), loginSuccessful, policyReject, attributes);
    }

    private LTAttrs createAttributes(LoginCredentials credentials) {
        LTAttrs attributes = new LTAttrs();
        attributes.add("client_id", credentials.getUserAgent());
        attributes.add("protocol", "mobileapi");
        return attributes;
    }

}

==> open-xchange-mobile-api-facade_1.4.12.orig.tar.bz2: open-xchange-mobile-api-facade-1.4.12/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/weakforce/WeakforceService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.weakforce;

import com.openexchange.mobile.api.facade.auth.LoginCredentials;
import com.openexchange.mobile.api.facade.configuration.HostConfiguration;
import com.openexchange.mobile.api.facade.connectors.impl.WeakforceAllowConnector;
import com.openexchange.mobile.api.facade.connectors.impl.WeakforceReportConnector;
import com.openexchange.mobile.api.facade.exceptions.ApiFacadeException;
import com.openexchange.mobile.api.facade.utils.WeakforceUtil;
import com.openexchange.mobile.api.facade.weakforce.models.AllowResponse;
import com.openexchange.mobile.api.facade.weakforce.models.LTAttrs;
import com.openexchange.mobile.api.facade.weakforce.models.LoginTupleAllow;
import com.openexchange.mobile.api.facade.weakforce.models.LoginTupleReport;
import com.openexchange.mobile.api.facade.weakforce.models.ReportResponse;

public class WeakforceService {

    public AllowResponse allow(HostConfiguration configuration, LoginCredentials credentials) {
        LoginTupleAllow requestBody = createLoginTupleAllow(configuration, credentials);
        WeakforceAllowConnector connector = new WeakforceAllowConnector(configuration, requestBody);
        return connector.execute();
    }

    /*private*/ LoginTupleAllow createLoginTupleAllow(HostConfiguration configuration, LoginCredentials credentials) {
        String passwordHash = WeakforceUtil.generatePasswordHash(configuration, credentials);
        String deviceId = credentials.getUserAgent();
        String protocol = credentials.getForwardedProto();
        LTAttrs attributes = createAttributes(credentials);
        return new LoginTupleAllow(credentials.getUsername(), passwordHash, credentials.getRemoteIp(), deviceId, Protocol.HTTP, Protocol.isTls(protocol), attributes);
    }

    public void report(HostConfiguration configuration, LoginCredentials credentials, boolean loginSuccessful, boolean policyReject) {
        LoginTupleReport requestBody = createLoginTupleReport(configuration, credentials, loginSuccessful, policyReject);
        WeakforceReportConnector connector = new WeakforceReportConnector(configuration, requestBody);
        ReportResponse response = connector.execute();
        if (response == null || !"ok".equals(response.getStatus())) {
            throw ApiFacadeException.internalServerError("Failed to connect to weakforce");
        }
    }

    /*private*/ LoginTupleReport createLoginTupleReport(HostConfiguration configuration, LoginCredentials credentials, boolean loginSuccessful, boolean policyReject) {
        String passwordHash = WeakforceUtil.generatePasswordHash(configuration, credentials);
        String deviceId = credentials.getUserAgent();
        String protocol = credentials.getForwardedProto();
        LTAttrs attributes = createAttributes(credentials);
        return new LoginTupleReport(credentials.getUsername(), passwordHash, credentials.getRemoteIp(), deviceId, Protocol.HTTP, Protocol.isTls(protocol), loginSuccessful, policyReject, attributes);
    }

    private LTAttrs createAttributes(LoginCredentials credentials) {
        LTAttrs attributes = new LTAttrs();
        return attributes;
    }

}
